summaryrefslogtreecommitdiffhomepage
path: root/dhcpv6/option_domainsearchlist.go
diff options
context:
space:
mode:
Diffstat (limited to 'dhcpv6/option_domainsearchlist.go')
-rw-r--r--dhcpv6/option_domainsearchlist.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/dhcpv6/option_domainsearchlist.go b/dhcpv6/option_domainsearchlist.go
index 402c68e..6e5504c 100644
--- a/dhcpv6/option_domainsearchlist.go
+++ b/dhcpv6/option_domainsearchlist.go
@@ -8,18 +8,18 @@ import (
"fmt"
)
// OptDomainSearchList list implements a DOMAIN_SEARCH_LIST option
type OptDomainSearchList struct {
DomainSearchList []string
}
func (op *OptDomainSearchList) Code() OptionCode {
- return DOMAIN_SEARCH_LIST
+ return OptionDomainSearchList
}
func (op *OptDomainSearchList) ToBytes() []byte {
buf := make([]byte, 4)
- binary.BigEndian.PutUint16(buf[0:2], uint16(DOMAIN_SEARCH_LIST))
+ binary.BigEndian.PutUint16(buf[0:2], uint16(OptionDomainSearchList))
binary.BigEndian.PutUint16(buf[2:4], uint16(op.Length()))
buf = append(buf, LabelsToBytes(op.DomainSearchList)...)
return buf
@@ -8,18 +8,18 @@ import (
"fmt"
)
-// OptDomainSearchList list implements a DOMAIN_SEARCH_LIST option
+// OptDomainSearchList list implements a OptionDomainSearchList option
type OptDomainSearchList struct {
DomainSearchList []string